<?php namespace EscapeWork\Manager\Subscribers\Models;

use EscapeWork\LaravelHelpers\BaseModel;

class Subscriber extends BaseModel
{

    /**
     * Tabela
     */
    protected $table = 'subscribers';

    /**
     * Validation rules
     */
    public $validationRules = array(
        'email' => array('required', 'email'),
    );

    /**
     * Validation messages
     */
    public $validationMessages = array(
        'email.required' => 'Preencha o seu email',
        'email.email'    => 'Preencha um email válido',
    );

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id',
        'name',
        'email',
        'gender',
        'born_date',
        'city',
        'state',
        'country',
        'created_at',
        'updated_at',
    );

    public function groups()
    {
        return $this->belongsToMany('EscapeWork\Manager\Subscribers\Models\SubscriberGroup', 'subscriber_groups', 'subscriber_id', 'subscriber_group_id');
    }

    public function scopeJoinGroups($query)
    {
        return $query->leftJoin('subscriber_groups', 'subscribers.id', '=', 'subscriber_groups.subscriber_id');
    }

    public function setEmailAttribute($email)
    {
        $this->attributes['email'] = strtolower($email);
    }

    public function setGenderAttribute($value)
    {
        $accepted = array('m', 'f');

        if (in_array($value, $accepted)) {
            $this->attributes['gender'] = $value;
        }
    }

    public function setBornDateAttribute($value)
    {
        $this->_setDateAttribute('born_date', $value);
    }
}
