<?php namespace EscapeWork\Manager\Subscribers\Repositories;

use EscapeWork\LaravelHelpers\BaseRepository;
use EscapeWork\Manager\Subscribers\Models\Subscriber;
use Carbon\Carbon;

class SubscriberRepository extends BaseRepository
{

    public function __construct(Subscriber $subscriber)
    {
        $this->model = $subscriber;
    }

    public function filterAndPaginate(array $params = array())
    {
        $query = $this->model->newQuery();

        if (isset($params['name']) && $params['name'] != '') {
            $query->where('name', 'like', '%'.$params['name'].'%');
        }

        if (isset($params['email']) && $params['email'] != '') {
            $query->where('email', 'like', '%'.$params['email'].'%');
        }

        return $query->paginate();
    }

    public function save($groups = array())
    {
        if (! $this->model->exists && $subscriber = $this->model->where('email', '=', $this->model->email)->first()) {
            $this->model->exists = true;
            $this->model->id     = $subscriber->id;
        }

        $this->model->save();

        # salvando os grupos
        $this->model->groups()->sync((array) $groups);
    }

    public function getNewerSubscribers($group = null)
    {
        $yesterday = new Carbon();
        $yesterday->modify('-1 day');
        $date      = $yesterday->format('Y-m-d \0\0:\0\0:\0\0');

        $query = $this->model
                      ->where(function($query) use($date) {
                            $query->where('created_at', '>=', $date)
                                  ->orWhere('updated_at', '>=', $date);
                        });

        if ($group) {
            $query->joinGroups()
                  ->where('subscriber_groups.subscriber_group_id', '=', $group->id);
        }

        return $query->get();
    }
}
