@extends(Config::get('manager::views.layouts.master'))

@section('content')
    {{
        Form::manager_breadcrumb(array(
            route('manager.subscribers.index') => 'Contatos da newsletter',
            $edit ? 'Editar' : 'Inserir'
        ))
    }}

    {{
        Form::manager_page_header(
            'Contatos da newsletter',
            $edit ? 'Editar contato' : 'Inserir contato',
            array('route' => route('manager.subscribers.index'), 'label' => 'Cancelar')
        )
    }}

    @include('manager::inc.messages')

    <form action="{{ !$edit ? route('manager.subscribers.store') : route('manager.subscribers.update', $subscriber->id) }}" method="post" id="form-subscriber" class="form-horizontal" enctype="multipart/form-data">
        <input type="hidden" name="_token" value="{{ csrf_token() }}">
        @if ($edit)
            <input type="hidden" name="_method" value="put">
        @endif

        <fieldset>
            @section('fields')
                {{ Form::manager_form_group_input([
                    'label'      => 'Nome',
                    'type'       => 'text',
                    'name'       => 'name',
                    'id'         => 'name',
                    'value'      => $subscriber->name,
                    'required'   => false,
                    'autofocus'  => true
                ]) }}

                {{ Form::manager_form_group_input([
                    'label'      => 'E-mail',
                    'type'       => 'email',
                    'name'       => 'email',
                    'id'         => 'email',
                    'value'      => $subscriber->email,
                    'required'   => true
                ]) }}

                <div class="form-group">
                    <label for="gender" class="control-label col-sm-2">Sexo</label>

                    <div class="col-sm-8">
                        <div class="radio">
                            <label>
                                <input type="radio" name="gender" value="m" {{ $subscriber->gender == 'm' ? 'checked="checked"' : null }}>
                                Masculino
                            </label>
                        </div>

                        <div class="radio">
                            <label>
                                <input type="radio" name="gender" value="f" {{ $subscriber->gender == 'f' ? 'checked="checked"' : null }}>
                                Feminino
                            </label>
                        </div>
                    </div>
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="born_date" class="control-label col-sm-2">Data de nascimento</label>

                    <div class="col-sm-2">
                        <div class="input-group">
                            <input type="text" name="born_date" id="born_date" class="form-control" value="{{ !is_null($subscriber->born_date) ? date('d/m/Y', strtotime($subscriber->born_date)) : null }}" maxlength="255" data-date>
                            <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                        </div><!-- .input-append -->

                        <span class="help-block">dd/mm/aaaa</span>
                    </div>
                </div><!-- .form-group -->

                {{ Form::manager_form_group_input([
                    'label'      => 'Cidade',
                    'type'       => 'text',
                    'name'       => 'city',
                    'id'         => 'city',
                    'value'      => $subscriber->city,
                    'required'   => false
                ]) }}

                {{ Form::manager_form_group_input([
                    'label'      => 'Estado',
                    'type'       => 'text',
                    'name'       => 'state',
                    'id'         => 'state',
                    'value'      => $subscriber->state,
                    'required'   => false
                ]) }}

                {{ Form::manager_form_group_input([
                    'label'      => 'País',
                    'type'       => 'text',
                    'name'       => 'country',
                    'id'         => 'country',
                    'value'      => $subscriber->country,
                    'required'   => false
                ]) }}

                @if ($groups->count() > 0)
                    <div class="form-group">
                        <label class="control-label col-sm-2">Grupos</label>

                        <div class="col-sm-8">
                            @foreach ($groups as $group)
                                <div class="checkbox">
                                    <label>
                                        <input type="checkbox" name="groups[{{ $group->id }}]" value="{{ $group->id }}" {{ $subscriber->groups->contains($group->id) ? 'checked="checked"' : null }}>
                                        {{ $group->title }}
                                    </label>
                                </div>
                            @endforeach
                        </div><!-- .col-sm-8 -->
                    </div>
                @endif
            @show
        </fieldset>

        <div class="row">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Salvando...">Salvar</button>
                <a href="{{ route('manager.subscribers.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-actions -->
    </form>
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        $('[data-date]').mask('99/99/9999');

        $('#form-subscriber').on('submit', function() {
            $(this).find('.js-btn-submit').button('loading');
        });
    })();
    </script>
@stop
